@@ -1,3 +1,4 @@
+"""Handle file paths as command arguments."""
 import typing
 
 from mitmproxy import command
@@ -7,9 +8,6 @@ from mitmproxy import types
 
 
 class MyAddon:
-    def __init__(self):
-        self.num = 0
-
     @command.command("myaddon.histogram")
     def histogram(
         self,
@@ -22,7 +20,7 @@ class MyAddon:
 
         with open(path, "w+") as fp:
             for cnt, dom in sorted([(v, k) for (k, v) in totals.items()]):
-                fp.write("%s: %s\n" % (cnt, dom))
+                fp.write(f"{cnt}: {dom}\n")
 
         ctx.log.alert("done")
 
