@@ -8,9 +8,10 @@ from mitmproxy import connections  # noqa
 from mitmproxy import exceptions
 from mitmproxy import http
 from mitmproxy import flow
+from mitmproxy.net.http import url
 from mitmproxy.proxy.protocol import base
 from mitmproxy.proxy.protocol.websocket import WebSocketLayer
-from mitmproxy.net import websockets
+from mitmproxy.net import websocket
 
 
 class _HttpTransmissionLayer(base.Layer):
@@ -101,8 +102,8 @@ class UpstreamConnectLayer(base.Layer):
 
     def _send_connect_request(self):
         self.log("Sending CONNECT request", "debug", [
-            "Proxy Server: {}".format(self.ctx.server_conn.address),
-            "Connect to: {}:{}".format(self.connect_request.host, self.connect_request.port)
+            f"Proxy Server: {self.ctx.server_conn.address}",
+            f"Connect to: {self.connect_request.host}:{self.connect_request.port}"
         ])
         self.send_request(self.connect_request)
         resp = self.read_response(self.connect_request)
@@ -157,15 +158,15 @@ def validate_request_form(mode, request):
         if request.is_http2 and mode is HTTPMode.transparent and request.first_line_format == "absolute":
             return  # dirty hack: h2 may have authority info. will be fixed properly with sans-io.
         if mode == HTTPMode.transparent:
-            err_message = textwrap.dedent((
+            err_message = textwrap.dedent(
                 """
                 Mitmproxy received an {} request even though it is not running
                 in regular mode. This usually indicates a misconfiguration,
                 please see the mitmproxy mode documentation for details.
                 """
-            )).strip().format("HTTP CONNECT" if request.first_line_format == "authority" else "absolute-form")
+            ).strip().format("HTTP CONNECT" if request.first_line_format == "authority" else "absolute-form")
         else:
-            err_message = "Invalid HTTP request form (expected: %s, got: %s)" % (
+            err_message = "Invalid HTTP request form (expected: {}, got: {})".format(
                 " or ".join(allowed_request_forms), request.first_line_format
             )
         raise exceptions.HttpException(err_message)
@@ -313,7 +314,7 @@ class HttpLayer(base.Layer):
             self.log(
                 "request",
                 "warn",
-                ["HTTP protocol error in client request: {}".format(e)]
+                [f"HTTP protocol error in client request: {e}"]
             )
             return False
 
@@ -326,7 +327,10 @@ class HttpLayer(base.Layer):
 
         # update host header in reverse proxy mode
         if self.config.options.mode.startswith("reverse:") and not self.config.options.keep_host_header:
-            f.request.host_header = self.config.upstream_server.address[0]
+            f.request.host_header = url.hostport(
+                self.config.upstream_server.scheme,
+                *self.config.upstream_server.address
+            )
 
         # Determine .scheme, .host and .port attributes for inline scripts. For
         # absolute-form requests, they are directly given in the request. For
@@ -342,7 +346,11 @@ class HttpLayer(base.Layer):
         self.channel.ask("request", f)
 
         try:
-            if websockets.check_handshake(request.headers) and websockets.check_client_version(request.headers):
+            valid = (
+                websocket.check_handshake(request.headers) and
+                websocket.check_client_version(request.headers)
+            )
+            if valid:
                 f.metadata['websocket'] = True
                 # We only support RFC6455 with WebSocket version 13
                 # allow inline scripts to manipulate the client handshake
@@ -458,8 +466,8 @@ class HttpLayer(base.Layer):
                 # received after e.g. a WebSocket upgrade request.
                 # Check for WebSocket handshake
                 is_websocket = (
-                    websockets.check_handshake(f.request.headers) and
-                    websockets.check_handshake(f.response.headers)
+                    websocket.check_handshake(f.request.headers) and
+                    websocket.check_handshake(f.response.headers)
                 )
                 if is_websocket and not self.config.options.websocket:
                     self.log(
@@ -495,7 +503,7 @@ class HttpLayer(base.Layer):
             response = http.make_error_response(code, message, headers)
             self.send_response(response)
         except (exceptions.NetlibException, h2.exceptions.H2Error, exceptions.Http2ProtocolException):
-            self.log("Failed to send error response to client: {}".format(message), "debug")
+            self.log(f"Failed to send error response to client: {message}", "debug")
 
     def change_upstream_proxy_server(self, address):
         # Make set_upstream_proxy_server always available,
