@@ -4,18 +4,18 @@ import struct
 import tempfile
 import traceback
 
-from mitmproxy import options
-from mitmproxy import exceptions
+from wsproto.frame_protocol import Opcode
+
+from mitmproxy import exceptions, options
 from mitmproxy.http import HTTPFlow, make_connect_request
 from mitmproxy.websocket import WebSocketFlow
+from mitmproxy.net import http, tcp, websocket
+
+from pathod.language import websockets_frame
 
-from mitmproxy.net import tcp
-from mitmproxy.net import http
 from ...net import tservers as net_tservers
 from ... import tservers
 
-from mitmproxy.net import websockets
-
 
 class _WebSocketServerBase(net_tservers.ServerTestBase):
 
@@ -24,7 +24,7 @@ class _WebSocketServerBase(net_tservers.ServerTestBase):
         def handle(self):
             try:
                 request = http.http1.read_request(self.rfile)
-                assert websockets.check_handshake(request.headers)
+                assert websocket.check_handshake(request.headers)
 
                 response = http.Response(
                     http_version=b"HTTP/1.1",
@@ -123,7 +123,7 @@ class _WebSocketTestBase:
         self.client.wfile.flush()
 
         response = http.http1.read_response(self.client.rfile, request)
-        assert websockets.check_handshake(response.headers)
+        assert websocket.check_handshake(response.headers)
 
 
 class _WebSocketTest(_WebSocketTestBase, _WebSocketServerBase):
@@ -143,15 +143,15 @@ class TestSimple(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.TEXT, payload=b'server-foobar')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.TEXT, payload=b'server-foobar')))
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=frame.header.opcode, payload=frame.payload)))
+        header, frame, _ = websocket.read_frame(rfile)
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=header.opcode, payload=frame.payload)))
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=frame.header.opcode, payload=frame.payload)))
+        header, frame, _ = websocket.read_frame(rfile)
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=header.opcode, payload=frame.payload)))
         wfile.flush()
 
     @pytest.mark.parametrize('streaming', [True, False])
@@ -163,22 +163,22 @@ class TestSimple(_WebSocketTest):
         self.proxy.set_addons(Stream())
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'server-foobar'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.TEXT, payload=b'self.client-foobar')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.TEXT, payload=b'self.client-foobar')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'self.client-foobar'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.BINARY, payload=b'\xde\xad\xbe\xef')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.BINARY, payload=b'\xde\xad\xbe\xef')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'\xde\xad\xbe\xef'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE)))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE)))
         self.client.wfile.flush()
 
         assert len(self.master.state.flows) == 2
@@ -186,15 +186,15 @@ class TestSimple(_WebSocketTest):
         assert isinstance(self.master.state.flows[1], WebSocketFlow)
         assert len(self.master.state.flows[1].messages) == 5
         assert self.master.state.flows[1].messages[0].content == 'server-foobar'
-        assert self.master.state.flows[1].messages[0].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[0].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[1].content == 'self.client-foobar'
-        assert self.master.state.flows[1].messages[1].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[1].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[2].content == 'self.client-foobar'
-        assert self.master.state.flows[1].messages[2].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[2].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[3].content == b'\xde\xad\xbe\xef'
-        assert self.master.state.flows[1].messages[3].type == websockets.OPCODE.BINARY
+        assert self.master.state.flows[1].messages[3].type == Opcode.BINARY
         assert self.master.state.flows[1].messages[4].content == b'\xde\xad\xbe\xef'
-        assert self.master.state.flows[1].messages[4].type == websockets.OPCODE.BINARY
+        assert self.master.state.flows[1].messages[4].type == Opcode.BINARY
 
     def test_change_payload(self):
         class Addon:
@@ -204,19 +204,19 @@ class TestSimple(_WebSocketTest):
         self.proxy.set_addons(Addon())
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'foo'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.TEXT, payload=b'self.client-foobar')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.TEXT, payload=b'self.client-foobar')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'foo'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.BINARY, payload=b'\xde\xad\xbe\xef')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.BINARY, payload=b'\xde\xad\xbe\xef')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'foo'
 
 
@@ -224,7 +224,7 @@ class TestKillFlow(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.TEXT, payload=b'server-foobar')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.TEXT, payload=b'server-foobar')))
         wfile.flush()
 
     def test_kill(self):
@@ -236,7 +236,7 @@ class TestKillFlow(_WebSocketTest):
         self.setup_connection()
 
         with pytest.raises(exceptions.TcpDisconnect):
-            websockets.Frame.from_file(self.client.rfile)
+            _ = websocket.read_frame(self.client.rfile, False)
 
 
 class TestSimpleTLS(_WebSocketTest):
@@ -244,26 +244,26 @@ class TestSimpleTLS(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.TEXT, payload=b'server-foobar')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.TEXT, payload=b'server-foobar')))
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=frame.header.opcode, payload=frame.payload)))
+        header, frame, _ = websocket.read_frame(rfile)
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=header.opcode, payload=frame.payload)))
         wfile.flush()
 
     def test_simple_tls(self):
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'server-foobar'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.TEXT, payload=b'self.client-foobar')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.TEXT, payload=b'self.client-foobar')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         assert frame.payload == b'self.client-foobar'
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE)))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE)))
         self.client.wfile.flush()
 
 
@@ -271,29 +271,29 @@ class TestPing(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.PING, payload=b'foobar')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.PING, payload=b'foobar')))
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        assert frame.header.opcode == websockets.OPCODE.PONG
+        header, frame, _ = websocket.read_frame(rfile)
+        assert header.opcode == Opcode.PONG
         assert frame.payload == b'foobar'
 
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.PONG, payload=b'done')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.PONG, payload=b'done')))
         wfile.flush()
 
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.CLOSE)))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.CLOSE)))
         wfile.flush()
-        websockets.Frame.from_file(rfile)
+        _ = websocket.read_frame(rfile, False)
 
     @pytest.mark.asyncio
     async def test_ping(self):
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        websockets.Frame.from_file(self.client.rfile)
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE)))
+        header, frame, _ = websocket.read_frame(self.client.rfile)
+        _ = websocket.read_frame(self.client.rfile, False)
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE)))
         self.client.wfile.flush()
-        assert frame.header.opcode == websockets.OPCODE.PING
+        assert header.opcode == Opcode.PING
         assert frame.payload == b''  # We don't send payload to other end
 
         assert await self.master.await_log("Pong Received from server", "info")
@@ -303,30 +303,30 @@ class TestPong(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        frame = websockets.Frame.from_file(rfile)
-        assert frame.header.opcode == websockets.OPCODE.PING
+        header, frame, _ = websocket.read_frame(rfile)
+        assert header.opcode == Opcode.PING
         assert frame.payload == b''
 
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.PONG, payload=frame.payload)))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.PONG, payload=frame.payload)))
         wfile.flush()
 
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.CLOSE)))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.CLOSE)))
         wfile.flush()
-        websockets.Frame.from_file(rfile)
+        _ = websocket.read_frame(rfile)
 
     @pytest.mark.asyncio
     async def test_pong(self):
         self.setup_connection()
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.PING, payload=b'foobar')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.PING, payload=b'foobar')))
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        websockets.Frame.from_file(self.client.rfile)
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE)))
+        header, frame, _ = websocket.read_frame(self.client.rfile)
+        _ = websocket.read_frame(self.client.rfile)
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE)))
         self.client.wfile.flush()
 
-        assert frame.header.opcode == websockets.OPCODE.PONG
+        assert header.opcode == Opcode.PONG
         assert frame.payload == b'foobar'
         assert await self.master.await_log("pong received")
 
@@ -335,57 +335,56 @@ class TestClose(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        frame = websockets.Frame.from_file(rfile)
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=frame.header.opcode, payload=frame.payload)))
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.CLOSE)))
+        header, frame, _ = websocket.read_frame(rfile)
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=header.opcode, payload=frame.payload)))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.CLOSE)))
         wfile.flush()
 
         with pytest.raises(exceptions.TcpDisconnect):
-            websockets.Frame.from_file(rfile)
+            _ = websocket.read_frame(rfile)
 
     def test_close(self):
         self.setup_connection()
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE)))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE)))
         self.client.wfile.flush()
 
-        websockets.Frame.from_file(self.client.rfile)
+        _ = websocket.read_frame(self.client.rfile)
         with pytest.raises(exceptions.TcpDisconnect):
-            websockets.Frame.from_file(self.client.rfile)
+            _ = websocket.read_frame(self.client.rfile)
 
     def test_close_payload_1(self):
         self.setup_connection()
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE, payload=b'\00\42')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE, payload=b'\00\42')))
         self.client.wfile.flush()
 
-        websockets.Frame.from_file(self.client.rfile)
+        _ = websocket.read_frame(self.client.rfile)
         with pytest.raises(exceptions.TcpDisconnect):
-            websockets.Frame.from_file(self.client.rfile)
+            _ = websocket.read_frame(self.client.rfile)
 
     def test_close_payload_2(self):
         self.setup_connection()
 
-        self.client.wfile.write(bytes(websockets.Frame(fin=1, mask=1, opcode=websockets.OPCODE.CLOSE, payload=b'\00\42foobar')))
+        self.client.wfile.write(bytes(websockets_frame.Frame(fin=1, mask=1, opcode=Opcode.CLOSE, payload=b'\00\42foobar')))
         self.client.wfile.flush()
 
-        websockets.Frame.from_file(self.client.rfile)
+        _ = websocket.read_frame(self.client.rfile)
         with pytest.raises(exceptions.TcpDisconnect):
-            websockets.Frame.from_file(self.client.rfile)
+            _ = websocket.read_frame(self.client.rfile)
 
 
 class TestInvalidFrame(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=15, payload=b'foobar')))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=15, payload=b'foobar')))
         wfile.flush()
 
     def test_invalid_frame(self):
         self.setup_connection()
 
-        # with pytest.raises(exceptions.TcpDisconnect):
-        frame = websockets.Frame.from_file(self.client.rfile)
+        _, frame, _ = websocket.read_frame(self.client.rfile)
         code, = struct.unpack('!H', frame.payload[:2])
         assert code == 1002
         assert frame.payload[2:].startswith(b'Invalid opcode')
@@ -395,7 +394,7 @@ class TestStreaming(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        wfile.write(bytes(websockets.Frame(opcode=websockets.OPCODE.TEXT, payload=b'server-foobar')))
+        wfile.write(bytes(websockets_frame.Frame(opcode=Opcode.TEXT, payload=b'server-foobar')))
         wfile.flush()
 
     @pytest.mark.parametrize('streaming', [True, False])
@@ -410,11 +409,11 @@ class TestStreaming(_WebSocketTest):
         frame = None
         if not streaming:
             with pytest.raises(exceptions.TcpDisconnect):  # Reader.safe_read get nothing as result
-                frame = websockets.Frame.from_file(self.client.rfile)
+                _, frame, _ = websocket.read_frame(self.client.rfile)
             assert frame is None
 
         else:
-            frame = websockets.Frame.from_file(self.client.rfile)
+            _, frame, _ = websocket.read_frame(self.client.rfile)
 
             assert frame
             assert self.master.state.flows[1].messages == []  # Message not appended as the final frame isn't received
@@ -427,45 +426,45 @@ class TestExtension(_WebSocketTest):
         wfile.write(b'\xc1\x0f*N-*K-\xd2M\xcb\xcfOJ,\x02\x00')
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        assert frame.header.rsv1
+        header, _, _ = websocket.read_frame(rfile)
+        assert header.rsv.rsv1
         wfile.write(b'\xc1\nJ\xce\xc9L\xcd+\x81r\x00\x00')
         wfile.flush()
 
-        frame = websockets.Frame.from_file(rfile)
-        assert frame.header.rsv1
+        header, _, _ = websocket.read_frame(rfile)
+        assert header.rsv.rsv1
         wfile.write(b'\xc2\x07\xba\xb7v\xdf{\x00\x00')
         wfile.flush()
 
     def test_extension(self):
         self.setup_connection(True)
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        assert frame.header.rsv1
+        header, _, _ = websocket.read_frame(self.client.rfile)
+        assert header.rsv.rsv1
 
         self.client.wfile.write(b'\xc1\x8fQ\xb7vX\x1by\xbf\x14\x9c\x9c\xa7\x15\x9ax9\x12}\xb5v')
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        assert frame.header.rsv1
+        header, _, _ = websocket.read_frame(self.client.rfile)
+        assert header.rsv.rsv1
 
         self.client.wfile.write(b'\xc2\x87\xeb\xbb\x0csQ\x0cz\xac\x90\xbb\x0c')
         self.client.wfile.flush()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        assert frame.header.rsv1
+        header, _, _ = websocket.read_frame(self.client.rfile)
+        assert header.rsv.rsv1
 
         assert len(self.master.state.flows[1].messages) == 5
         assert self.master.state.flows[1].messages[0].content == 'server-foobar'
-        assert self.master.state.flows[1].messages[0].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[0].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[1].content == 'client-foobar'
-        assert self.master.state.flows[1].messages[1].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[1].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[2].content == 'client-foobar'
-        assert self.master.state.flows[1].messages[2].type == websockets.OPCODE.TEXT
+        assert self.master.state.flows[1].messages[2].type == Opcode.TEXT
         assert self.master.state.flows[1].messages[3].content == b'\xde\xad\xbe\xef'
-        assert self.master.state.flows[1].messages[3].type == websockets.OPCODE.BINARY
+        assert self.master.state.flows[1].messages[3].type == Opcode.BINARY
         assert self.master.state.flows[1].messages[4].content == b'\xde\xad\xbe\xef'
-        assert self.master.state.flows[1].messages[4].type == websockets.OPCODE.BINARY
+        assert self.master.state.flows[1].messages[4].type == Opcode.BINARY
 
 
 class TestInjectMessageClient(_WebSocketTest):
@@ -482,8 +481,8 @@ class TestInjectMessageClient(_WebSocketTest):
         self.proxy.set_addons(Inject())
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        assert frame.header.opcode == websockets.OPCODE.TEXT
+        header, frame, _ = websocket.read_frame(self.client.rfile)
+        assert header.opcode == Opcode.TEXT
         assert frame.payload == b'This is an injected message!'
 
 
@@ -491,11 +490,11 @@ class TestInjectMessageServer(_WebSocketTest):
 
     @classmethod
     def handle_websockets(cls, rfile, wfile):
-        frame = websockets.Frame.from_file(rfile)
-        assert frame.header.opcode == websockets.OPCODE.TEXT
+        header, frame, _ = websocket.read_frame(rfile)
+        assert header.opcode == Opcode.TEXT
         success = frame.payload == b'This is an injected message!'
 
-        wfile.write(bytes(websockets.Frame(fin=1, opcode=websockets.OPCODE.TEXT, payload=str(success).encode())))
+        wfile.write(bytes(websockets_frame.Frame(fin=1, opcode=Opcode.TEXT, payload=str(success).encode())))
         wfile.flush()
 
     def test_inject_message_server(self):
@@ -506,6 +505,6 @@ class TestInjectMessageServer(_WebSocketTest):
         self.proxy.set_addons(Inject())
         self.setup_connection()
 
-        frame = websockets.Frame.from_file(self.client.rfile)
-        assert frame.header.opcode == websockets.OPCODE.TEXT
+        header, frame, _ = websocket.read_frame(self.client.rfile)
+        assert header.opcode == Opcode.TEXT
         assert frame.payload == b'True'
